@@ -44,8 +44,31 @@ class TokenTests(utils.ClientTestCase, testresources.ResourcedTestCase):
         self.stub_url('GET', ['auth', 'tokens', 'OS-PKI', 'revoked'],
                       json=sample_revoked_response)
         resp = self.client.tokens.get_revoked()
+        self.assertQueryStringIs()
         self.assertEqual(sample_revoked_response, resp)
 
+    def test_get_revoked_audit_id_only(self):
+        # When get_revoked(audit_id_only=True) then ?audit_id_only is set on
+        # the request.
+        sample_revoked_response = {
+            'revoked': [
+                {
+                    'audit_id': uuid.uuid4().hex,
+                    'expires': '2016-01-21T15:53:52Z',
+                },
+            ],
+        }
+        self.stub_url('GET', ['auth', 'tokens', 'OS-PKI', 'revoked'],
+                      json=sample_revoked_response)
+        resp = self.client.tokens.get_revoked(audit_id_only=True)
+        self.assertQueryStringIs('audit_id_only')
+        self.assertEqual(sample_revoked_response, resp)
+
+    def test_get_revoked_audit_id_only_positional_exc(self):
+        # When get_revoked(True) an exception is raised because this must be
+        # called with named parameter.
+        self.assertRaises(TypeError, self.client.tokens.get_revoked, True)
+
     def test_validate_token_with_token_id(self):
         # Can validate a token passing a string token ID.
         token_id = uuid.uuid4().hex
