@@ -22,6 +22,7 @@ from keystoneclient import exceptions
 @six.add_metaclass(abc.ABCMeta)
 class EntityManager(base.Manager):
     """Manager class for listing federated accessible objects."""
+
     resource_class = None
 
     @abc.abstractproperty
@@ -29,10 +30,10 @@ class EntityManager(base.Manager):
         raise exceptions.MethodNotImplemented
 
     def list(self):
-        url = '/OS-FEDERATION/%s' % self.object_type
+        url = '/auth/%s' % self.object_type
         try:
             tenant_list = self._list(url, self.object_type)
-        except exceptions.EndpointNotFound:
+        except exceptions.EndpointException:
             endpoint_filter = {'interface': base_auth.AUTH_INTERFACE}
             tenant_list = self._list(url, self.object_type,
                                      endpoint_filter=endpoint_filter)
