@@ -19,13 +19,12 @@ OAUTH_PATH = '/OS-OAUTH1'
 
 
 def get_oauth_token_from_body(body):
-    """Parse the URL response body to retrieve the oauth token key and secret
+    """Parse the URL response body to retrieve the oauth token key and secret.
 
     The response body will look like:
     'oauth_token=12345&oauth_token_secret=67890' with
     'oauth_expires_at=2013-03-30T05:27:19.463201' possibly there, too.
     """
-
     if six.PY3:
         body = body.decode('utf-8')
 
